# -*- coding: utf-8 -*-
import unittest


class BaseTestCase(unittest.TestCase):
    """
    Basically a dummy, but doing this for consistency with other
    packages.
    """

    def test_import(self):
        from calmjs.types import exceptions
        self.assertTrue(hasattr(exceptions, 'ToolchainAbort'))



import unittest
from os.path import dirname


def make_suite():  # pragma: no cover
    test_loader = unittest.TestLoader()
    test_suite = test_loader.discover(
        'calmjs.types.tests', pattern='test_*.py',
        top_level_dir=dirname(__file__),
    )
    return test_suite
